% Title: GHK_algorithm.m
% Date: 5/15/2015
% Author: Kevin Lim
% Description: 
%   This file implements the bvp4c boundary value problem solver to solve 
%   the GHK model, when the model admits equilibria with at most three 
%   regions of sorting of workers and managers to sectors.
%
%   The function input is a structure param, with three fields:
%       1. param.sec, with fields storing sector-specific parameters
%           - {gam_i,alp_i,bet_i,rho_i,psi_i}, i = 1,2, where output per 
%             manager with quality q_H in sector i is:
%                   x_i = psi_i(q_H,q_L)*l_i^ gam_i
%             and the productivity function is:
%                   psi_i(q_H,q_L) = (alp_i*q_L^rho_i+bet_i*q_H^rho_i)^...
%                       ((alp_i+bet_i)/rho_i)
%           - {p_i}, i = 1,2, where p_i is the goods price in sector i
%       2. param.fac, with fields storing factor-specific parameters
%           - qL_min: worker ability distribution, lower bound
%           - qL_max: worker ability distribution, upper bound
%           - qH_min: manager ability distribution, lower bound
%           - qH_max: manager ability distribution, upper bound
%           - L: aggregate worker endowment
%           - H: aggregate manager endowment
%           - phi_L: pdf over worker ability
%           - phi_H: pdf over manager ability
%       3. param.sol, with fields storing solver-specific parameters (all
%          these parameters can be omitted, in which case default values
%          wil be used)
%           - eq_type: order of equilibrium types to look for
%                       - 1: single-sector
%                       - 2: two-sector HH/LL
%                       - 3: two-sector HL/LH
%                       - 4: two-sector HH/MM/LL
%                       - 5: two-sector HM/MH/LL
%                       - 6: two-sector HH/ML/LM
%           - sol.init_wage: wage at qL=qL_min for initial guess of wage 
%                            solution
%           - sol.qL_gridSize: (approximate) number of gridpoints between
%                              qL_min and qL_max
%           - sol.salary_tol: tolerance for salary differentials
%           - sol.max_iter: maximum number of iterations
%           - sol.bvp4c_opt: options for bvp4c
%           - sol.qL_cutoff_manual: manual input for qL cutoff values for
%                                   equilibria with three regions of 
%                                   sorting
%   The function output is a structure stats, with fields storing 
%   statistics of interest:
%       - foundEq: indicator that equals 1 if equilibrium found, and 0 if 
%                  equilibrium not found
%       - foundEq_type: type of equilibrium found
%                           - 1: single-sector
%                           - 2: two-sector HH/LL
%                           - 3: two-sector HL/LH
%       - relabel: indicator that equals 1 if sectors have been relabeled
%       - qL_grid: qL grid from solver output (note that this will in
%                  general be different from the qL grid supplied as an 
%                  input to the solver)
%       - qH_grid: sorted values of match(qL_grid)
%       - wage: worker wage function, where wage(i) gives the wage paid to
%               a worker of ability qL_grid(i)
%       - salary: manager salary function, where salary(i) gives the
%                 salary paid to a manager of ability match(qL_grid(i))
%       - salary_sorted: sorted manager salary function, where salary(i)
%                        gives the salary paid to a manager of ability
%                        qH_grid(i)
%       - match: matching function, where match(i) is the ability of
%                managers that match to workers of quality qL_grid(i)
%       - qL_cutoff: qL cutoff value for sorting regions
%       - qH_cutoff: qH cutoff value for sorting regions
%       - qL_cutoff_index: index such that qL_grid(qL_cutoff_index) =
%                          qL_cutoff
%       - qH_cutoff_index: index such that qH_grid(qH_cutoff_index) =
%                          qH_cutoff
%       - output_1: output of sector 1
%       - output_2: output of sector 2

function stats = GHK_algorithm(param)

%% SECTION 1: extract parameters

% display starting message
disp('Solving...');
disp(' ');

% extract sector-specific parameters
gam_1 = param.sec.gam_1;
gam_2 = param.sec.gam_2;
alp_1 = param.sec.alp_1;
alp_2 = param.sec.alp_2;
bet_1 = param.sec.bet_1;
bet_2 = param.sec.bet_2;
rho_1 = param.sec.rho_1;
rho_2 = param.sec.rho_2;
psi_1 = param.sec.psi_1;
psi_2 = param.sec.psi_2;
p_1 = param.sec.p_1;
p_2 = param.sec.p_2;

% extract factor-specific parameters
qL_min = param.fac.qL_min;
qL_max = param.fac.qL_max;
qH_min = param.fac.qH_min;
qH_max = param.fac.qH_max;
L = param.fac.L;
H = param.fac.H;
phi_L = param.fac.phi_L;
phi_H = param.fac.phi_H;

% extract solver parameters and/or set default values
if isfield(param,'sol')
    if isfield(param.sol,'eq_type')
        eq_type = param.sol.eq_type;
    else
        eq_type = [1,2,3];
    end
    if isfield(param.sol,'init_wage')
        init_wage = param.sol.init_wage;
    else
        init_wage = .01;
    end
    if isfield(param.sol,'qL_gridSize')
        qL_gridSize = param.sol.qL_gridSize;
    else
        qL_gridSize = 200;
    end
    if isfield(param.sol,'salary_tol')
        salary_tol = param.sol.salary_tol;
    else
        salary_tol = 1E-5;
    end
    if isfield(param.sol,'max_iter')
        max_iter = param.sol.max_iter;
    else
        max_iter = 100;
    end
    if isfield(param.sol,'bvp4c_opt')
        bvp4c_opt = param.sol.bvp4c_opt;
    else
        bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
    end
    if isfield(param.sol,'disp_opt')
        disp_opt = param.sol.disp_opt;
    else
        disp_opt = 1;
    end
    if isfield(param.sol,'qL_cutoff_manual')
        qL_cutoff_manual = param.sol.qL_cutoff_manual;
    end
else
    eq_type = [1 2 3];  
    init_wage = .01;
    qL_gridSize = 200;
    salary_tol = 1E-5;
    max_iter = 100;
    bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
    disp_opt = 1;
end

%% Section 2: check sufficient conditions for sorting (equal rho only)

% initialize relabel indicator
relabel = 0;

if rho_1 == rho_2
   
    rho = rho_1;
    r_1 = bet_1/alp_1;
    r_2 = bet_2/alp_2;   
    s_1 = gam_1/gam_2*(alp_2+bet_2)/(alp_1+bet_1);
    s_2 = (1-gam_1)/(1-gam_2)*r_2/r_1*(alp_2+bet_2)...
            /(alp_1+bet_1);
    
    % HH/LL sorting
    if r_2 > r_1
        c_1 = (1+r_2*(qH_max/qL_min)^rho)/(1+r_1*(qH_max/qL_min)^rho);
        c_2 = (1+r_2*(qH_min/qL_max)^rho)/(1+r_1*(qH_min/qL_max)^rho);
    else
        c_1 = (1+r_2*(qH_min/qL_max)^rho)/(1+r_1*(qH_min/qL_max)^rho);
        c_2 = (1+r_2*(qH_max/qL_min)^rho)/(1+r_1*(qH_max/qL_min)^rho);
    end
    if c_1 > max(s_1,s_2)
        if disp_opt
            disp('   Sufficient conditions met for HH/LL equilibrium.')
            disp(' ');
        end
        eq_type = [1 2];
    end
    if c_2 < min(s_1,s_2)
         if disp_opt
            disp(['   Sufficient conditions met for HH/LL equilibrium'...
                  ' (sectors reversed).']);
            disp(' ');
         end
         eq_type = [1 2];
         relabel = 1;
    end

    % HL/LH sorting
    if r_2/r_1 < (qH_min/qH_max)^rho
        c_1 = (qL_max^rho+r_2*qH_max^rho)/(qL_max^rho+r_1*qH_min^rho);
    else
        c_1 = (qL_min^rho+r_2*qH_max^rho)/(qL_min^rho+r_1*qH_min^rho);
    end
    if r_2/r_1 > (qL_min/qL_max)^rho
        c_2 = (qL_min^rho+r_2*qH_min^rho)/(qL_max^rho+r_1*qH_min^rho);
    else
        c_2 = (qL_min^rho+r_2*qH_max^rho)/(qL_max^rho+r_1*qH_max^rho);
    end
    if r_2/r_1 < (qH_max/qH_min)^rho
        c_3 = (qL_min^rho+r_2*qH_min^rho)/(qL_min^rho+r_1*qH_max^rho);
    else
        c_3 = (qL_max^rho+r_2*qH_min^rho)/(qL_max^rho+r_1*qH_max^rho);
    end
    if r_2/r_1 > (qL_max/qL_min)^rho
        c_4 = (qL_max^rho+r_2*qH_max^rho)/(qL_min^rho+r_1*qH_max^rho);
    else
        c_4 = (qL_max^rho+r_2*qH_min^rho)/(qL_min^rho+r_1*qH_min^rho);
    end
    if  c_1 > s_1 && c_2 < s_2
        if disp_opt
            disp('   Sufficient conditions met for HL/LH equilibrium.')
            disp(' ');
        end
         eq_type = [1 3];
    end
    if c_3 < s_1 && c_4 > s_2
        if disp_opt
            disp(['   Sufficient conditions met for HL/LH equilibrium'...
                  ' (sectors reversed).']);
            disp(' ');
        end
         eq_type = [1 3];
         relabel = 1;
    end
end

if relabel
    if disp_opt
        disp('   Relabeling sectors.')
        disp(' ');
    end
    gam_1_store = gam_1;
    alp_1_store = alp_1;
    bet_1_store = bet_1;
    rho_1_store = rho_1;
    psi_1_store = psi_1;
    p_1_store = p_1;
    gam_1 = gam_2;
    alp_1 = alp_2;
    bet_1 = bet_2;
    rho_1 = rho_2;
    psi_1 = psi_2;
    p_1 = p_2;
    gam_2 = gam_1_store;
    alp_2 = alp_1_store;
    bet_2 = bet_1_store;
    rho_2 = rho_1_store;
    psi_2 = psi_1_store;
    p_2 = p_1_store;
end


%% SECTION 3: Solve for wage, salary, and matching functions using bvp4c

% initialize indicators
solve = 1;          % solver runs as long as solve = 1
foundEq = 0;        % indicactor equals 1 if equilibrium found, 0 otherwise
foundEq_type = 0;   % type of equilibrium found
                    %   - 0: no equlibrium found
                    %   - 1: single-sector
                    %   - 2: two-sector HH/LL
                    %   - 3: two-sector HL/LH

while solve
    
    % iterate over equilibrium types
    for ieq = 1:length(eq_type)

        % set equilibrium type being considered
        eq = eq_type(ieq);

        % initialize variables
        niter = 1;                  % iteration counter
        qL_cutoff_max = qL_max;     % upper bound for qL_cutoff guess
        qL_cutoff_min = qL_min;     % lower bound for qL_cutoff guess

        while foundEq == 0 && niter <= max_iter

            if eq == 1  % single-sector equilibrium

                % command window messages
                if niter == 1 && disp_opt
                    disp('   Looking for single-sector equilibrium:');
                end

                % set qL cutoff to qL_max
                qL_cutoff = qL_max;

                % set initial guess for bvp4c
                xinit = linspace(qL_min,qL_max,qL_gridSize);
                solinit = bvpinit(xinit,@yinit_1sec);

                % solve bvp and catch solver breakdown error
                try
                    sol = bvp4c(@odefun_1sec,@bcfun_1sec,solinit,...
                          bvp4c_opt);
                    qL_grid = sol.x';
                    wage = sol.y(1,:)';
                    match = sol.y(2,:)';
                catch err
                    if(strcmp(err.identifier,'MATLAB:bvp4c:SingJac'))
                        if disp_opt
                            disp('      Equilibrium not found.');
                            disp(' ');
                        end
                        break;
                    else
                        rethrow(err);
                    end
                end

                % Compute equilibrium salary function
                salary = computeSalary(gam_1,p_1,psi_1,qL_grid,wage,match);

                % Compute shadow profits of managers in sector 1 if they
                % switched to sector 2
                [m_inv_2,m_inv_ind_2] = computeShadowMatch(gam_2,...
                                                psi_2,qL_grid,wage,match);
                shadow_salary_1 = computeSalary(gam_2,p_2,psi_2,...
                                    m_inv_2,wage(m_inv_ind_2),match);


                % check if solution is consistent with equilibrium
                check_1 = min(salary - shadow_salary_1) > -salary_tol;
                if check_1 == 1
                    foundEq = 1;
                else
                    niter = max_iter;
                    if disp_opt
                        disp('      Equilibrium not found.');
                        disp(' ');
                    end
                end

            elseif eq == 2 || eq == 3 % two-sector equilibrium

                % command window messages                    
                if niter == 1 && disp_opt
                    if eq == 2
                        disp('   Looking for HH/LL equilibrium:');
                    elseif eq == 3
                        disp('   Looking for HL/LH equilibrium:');
                    end
                end

                % set current guess of qL cutoff
                qL_cutoff = (qL_cutoff_min+qL_cutoff_max)/2;

                % set initial guess for bvp4c
                xinit = [linspace(qL_min,qL_cutoff,floor(qL_gridSize/...
                         2)),linspace(qL_cutoff,qL_max,...
                         ceil(qL_gridSize/2))];
                if eq == 2
                    solinit = bvpinit(xinit,@yinit_2sec_HHLL);
                elseif eq == 3
                    solinit = bvpinit(xinit,@yinit_2sec_HLLH);
                end

                % solve bvp and catch solver breakdown error
                try
                    if eq == 2
                        sol = bvp4c(@odefun_2sec_2reg,@bcfun_2sec_HHLL,...
                              solinit,bvp4c_opt);
                    elseif eq == 3
                        sol = bvp4c(@odefun_2sec_2reg,@bcfun_2sec_HLLH,...
                              solinit,bvp4c_opt);
                    end
                    qL_grid = sol.x';
                    wage = sol.y(1,:)';
                    match = sol.y(2,:)';
                catch err
                    if(strcmp(err.identifier,'MATLAB:bvp4c:SingJac'))
                        if disp_opt
                            disp('      Equilibrium not found.');
                            disp(' ');
                        end
                        break;
                    else
                        rethrow(err);
                    end
                end

                % Compute equilibrium profit function
                salary_1 = computeSalary(gam_1,p_1,psi_1,...
                                            qL_grid,wage,match);
                salary_2 = computeSalary(gam_2,p_2,psi_2,...
                                            qL_grid,wage,match);
                salary = [salary_2(1:find(qL_grid==qL_cutoff,1));
                          salary_1(find(qL_grid==qL_cutoff,1)+1:end)];

                % Compute shadow profits of managers in sector 1 if they
                % switched to sector 2
                [m_inv_2,m_inv_ind_2] = computeShadowMatch(gam_2,...
                                                psi_2,qL_grid,wage,match);
                shadow_salary_1 = computeSalary(gam_2,p_2,psi_2,...
                                    m_inv_2,wage(m_inv_ind_2),match);

                % Compute shadow profits of managers in sector 2 if they
                % switched to sector 1
                [m_inv_1,m_inv_ind_1] = computeShadowMatch(gam_1,...
                                                psi_1,qL_grid,wage,match);
                shadow_salary_2 = computeSalary(gam_1,p_1,psi_1,...
                                    m_inv_1,wage(m_inv_ind_1),match);

                % Check if solution is consistent with equilibrium:
                %  - to determine the direction of adjustment for the 
                %    qL cutoff search, the algorithm omits checks for
                %    profitable deviations within the same sector
                %  - however, the final check for consistency with
                %    equilibrium is over the whole qL space

                % checks for profitable deviations over entire qL space
                check_1 = min(salary-shadow_salary_1) > -salary_tol;
                check_2 = min(salary-shadow_salary_2) > -salary_tol;

                % checks for profitable deviations from one sector to
                % another, including qL_cutoff
                check_1_adj = min(salary(qL_grid >= qL_cutoff) -...
                                shadow_salary_1(qL_grid >= qL_cutoff))...
                                > -salary_tol;
                check_2_adj = min(salary(qL_grid <= qL_cutoff) -...
                                shadow_salary_2(qL_grid <= qL_cutoff))...
                                > -salary_tol;

                % checks for profitable deviations from one sector to
                % another, excluding qL_cutoff
                check_1_adj_ex = min(salary(qL_grid > qL_cutoff) -...
                                shadow_salary_1(qL_grid > qL_cutoff))...
                                > -salary_tol;
                check_2_adj_ex = min(salary(qL_grid < qL_cutoff) -...
                                shadow_salary_2(qL_grid < qL_cutoff))...
                                > -salary_tol;


                % no profitable deviations found            
                if check_1 == 1 && check_2 == 1
                    % so equilibrium found
                    foundEq = 1;       
                % profitable deviations exist from high to low sector,
                % but not from low to high sector
                elseif check_1_adj == 0 && check_2_adj == 1
                    % so adjust qL cutoff upwards
                    qL_cutoff_min = qL_cutoff;
                % profitable deviations exist from low to high sector,
                % but not from high to low sector                        
                elseif check_1_adj == 1 && check_2_adj == 0
                    % so adjust qL cutoff downwards
                    qL_cutoff_max = qL_cutoff;
                else
                    if check_1_adj_ex == 0 && check_2_adj_ex == 1
                        qL_cutoff_min = qL_cutoff;
                    elseif check_1_adj_ex == 1 && check_2_adj_ex == 0
                        qL_cutoff_max = qL_cutoff;
                    else
                        if disp_opt
                            disp('      Equilibrium not found.');
                            disp(' ');
                        end
                        niter = max_iter;      
                    end
                end
                
            elseif eq == 4
                
                % command window messages                                        
                if niter == 1 && disp_opt
                    disp('   Looking for HH/MM/LL equilibrium:');
                end

                % set current guess of qL cutoff
                qL_cutoff(1) = qL_cutoff_manual(1);
                qL_cutoff(2) = qL_cutoff_manual(2);

                % set initial guess for bvp4c
                xinit = [linspace(qL_min,qL_cutoff(1),floor(qL_gridSize/...
                         3)) linspace(qL_cutoff(1),qL_cutoff(2),...
                         ceil(qL_gridSize/3)) linspace(qL_cutoff(2),...
                         qL_max,floor(qL_gridSize/3))];
                solinit = bvpinit(xinit,@yinit_2sec_HHMMLL);

                % catch solver breakdown error
                try
                    sol = bvp4c(@odefun_2sec_3reg,@bcfun_2sec_HHMMLL,...
                          solinit,bvp4c_opt);
                    qL_grid = sol.x';
                    wage = sol.y(1,:)';
                    match = sol.y(2,:)';
                catch err
                    if(strcmp(err.identifier,'MATLAB:bvp4c:SingJac'))
                        if disp_opt
                            disp('      Equilibrium not found.');
                            disp(' ');
                        end
                        break;
                    else
                        rethrow(err);
                    end
                end

                % Compute equilibrium profit function
                salary_1 = computeSalary(gam_1,p_1,psi_1,...
                                            qL_grid,wage,match);
                salary_2 = computeSalary(gam_2,p_2,psi_2,...
                                            qL_grid,wage,match);
                salary = [salary_1(1:find(sol.x==qL_cutoff(1),1));
                          salary_2(find(sol.x==qL_cutoff(1),1)+...
                          1:find(sol.x==qL_cutoff(2),1));
                          salary_1(find(sol.x==qL_cutoff(2),1)+1:end)];

                % Compute shadow profits of managers in sector 1 if they
                % switched to sector 2
                [m_inv_2,m_inv_ind_2] = computeShadowMatch(gam_2,psi_2,...
                                                qL_grid,wage,match);
                shadow_salary_1 = computeSalary(gam_2,p_2,psi_2,m_inv_2,...
                                        wage(m_inv_ind_2),match);

                % Compute shadow profits of managers in sector 2 if they
                % switched to sector 1
                [m_inv_1,m_inv_ind_1] = computeShadowMatch(gam_1,psi_1,...
                                            qL_grid,wage,match);
                shadow_salary_2 = computeSalary(gam_1,p_1,psi_1,m_inv_1,...
                                            wage(m_inv_ind_1),match);  

                % Check consistency with equilibrium
                
                % checks for profitable deviations over entire qL space
                check_1 = min(salary-shadow_salary_1) > -salary_tol;
                check_2 = min(salary-shadow_salary_2) > -salary_tol;

                % no profitable deviations found            
                if check_1 == 1 && check_2 == 1
                    % so equilibrium found
                    foundEq = 1;
                % profitable deviations found
                else
                    % so equilibrium not found
                    if disp_opt
                        disp('      Equilibrium not found');
                        disp(' ');
                    end
                    niter = max_iter;
                end
                    
            elseif eq == 5
                
                % command window messages                                        
                if niter == 1 && disp_opt
                    disp('   Looking for HM/MH/LL equilibrium:');
                end

                % set current guess of qL cutoff
                qL_cutoff(1) = qL_cutoff_manual(1);
                qL_cutoff(2) = qL_cutoff_manual(2);

                % set initial guess for bvp4c
                xinit = [linspace(qL_min,qL_cutoff(1),floor(qL_gridSize/...
                         3)) linspace(qL_cutoff(1),qL_cutoff(2),...
                         ceil(qL_gridSize/3)) linspace(qL_cutoff(2),...
                         qL_max,floor(qL_gridSize/3))];
                solinit = bvpinit(xinit,@yinit_2sec_HMMHLL);

                % catch solver breakdown error
                try
                    sol = bvp4c(@odefun_2sec_3reg,@bcfun_2sec_HMMHLL,...
                          solinit,bvp4c_opt);
                    qL_grid = sol.x';
                    wage = sol.y(1,:)';
                    match = sol.y(2,:)';
                catch err
                    if(strcmp(err.identifier,'MATLAB:bvp4c:SingJac'))
                        if disp_opt
                            disp('      Equilibrium not found.');
                            disp(' ');
                        end
                        break;
                    else
                        rethrow(err);
                    end
                end

                % Compute equilibrium profit function
                salary_1 = computeSalary(gam_1,p_1,psi_1,...
                                            qL_grid,wage,match);
                salary_2 = computeSalary(gam_2,p_2,psi_2,...
                                            qL_grid,wage,match);
                salary = [salary_1(1:find(sol.x==qL_cutoff(1),1));
                          salary_2(find(sol.x==qL_cutoff(1),1)+...
                          1:find(sol.x==qL_cutoff(2),1));
                          salary_1(find(sol.x==qL_cutoff(2),1)+1:end)];

                % Compute shadow profits of managers in sector 1 if they
                % switched to sector 2
                [m_inv_2,m_inv_ind_2] = computeShadowMatch(gam_2,psi_2,...
                                                qL_grid,wage,match);
                shadow_salary_1 = computeSalary(gam_2,p_2,psi_2,m_inv_2,...
                                        wage(m_inv_ind_2),match);

                % Compute shadow profits of managers in sector 2 if they
                % switched to sector 1
                [m_inv_1,m_inv_ind_1] = computeShadowMatch(gam_1,psi_1,...
                                            qL_grid,wage,match);
                shadow_salary_2 = computeSalary(gam_1,p_1,psi_1,m_inv_1,...
                                            wage(m_inv_ind_1),match);  

                % Check consistency with equilibrium
                
                % checks for profitable deviations over entire qL space
                check_1 = min(salary-shadow_salary_1) > -salary_tol;
                check_2 = min(salary-shadow_salary_2) > -salary_tol;
                
                % no profitable deviations found            
                if check_1 == 1 && check_2 == 1
                    % so equilibrium found
                    foundEq = 1;
                % profitable deviations found
                else
                    % so equilibrium not found
                    if disp_opt
                        disp('      Equilibrium not found');
                        disp(' ');
                    end
                    niter = max_iter;
                end
                    
            elseif eq == 6
                
                % command window messages                                        
                if niter == 1 && disp_opt
                    disp('   Looking for HH/ML/LM equilibrium:');
                end

                % set current guess of qL cutoff
                qL_cutoff(1) = qL_cutoff_manual(1);
                qL_cutoff(2) = qL_cutoff_manual(2);

                % set initial guess for bvp4c
                xinit = [linspace(qL_min,qL_cutoff(1),floor(qL_gridSize/...
                         3)) linspace(qL_cutoff(1),qL_cutoff(2),...
                         ceil(qL_gridSize/3)) linspace(qL_cutoff(2),...
                         qL_max,floor(qL_gridSize/3))];
                solinit = bvpinit(xinit,@yinit_2sec_HHMLLM);

                % catch solver breakdown error
                try
                    sol = bvp4c(@odefun_2sec_3reg,@bcfun_2sec_HHMLLM,...
                          solinit,bvp4c_opt);
                    qL_grid = sol.x';
                    wage = sol.y(1,:)';
                    match = sol.y(2,:)';
                catch err
                    if(strcmp(err.identifier,'MATLAB:bvp4c:SingJac'))
                        if disp_opt
                            disp('      Equilibrium not found.');
                            disp(' ');
                        end
                        break;
                    else
                        rethrow(err);
                    end
                end

                % Compute equilibrium profit function
                salary_1 = computeSalary(gam_1,p_1,psi_1,...
                                            qL_grid,wage,match);
                salary_2 = computeSalary(gam_2,p_2,psi_2,...
                                            qL_grid,wage,match);
                salary = [salary_1(1:find(sol.x==qL_cutoff(1),1));
                          salary_2(find(sol.x==qL_cutoff(1),1)+...
                          1:find(sol.x==qL_cutoff(2),1));
                          salary_1(find(sol.x==qL_cutoff(2),1)+1:end)];

                % Compute shadow profits of managers in sector 1 if they
                % switched to sector 2
                [m_inv_2,m_inv_ind_2] = computeShadowMatch(gam_2,psi_2,...
                                                qL_grid,wage,match);
                shadow_salary_1 = computeSalary(gam_2,p_2,psi_2,m_inv_2,...
                                        wage(m_inv_ind_2),match);

                % Compute shadow profits of managers in sector 2 if they
                % switched to sector 1
                [m_inv_1,m_inv_ind_1] = computeShadowMatch(gam_1,psi_1,...
                                            qL_grid,wage,match);
                shadow_salary_2 = computeSalary(gam_1,p_1,psi_1,m_inv_1,...
                                            wage(m_inv_ind_1),match);  

                % Check consistency with equilibrium
                
                % checks for profitable deviations over entire qL space
                check_1 = min(salary-shadow_salary_1) > -salary_tol;
                check_2 = min(salary-shadow_salary_2) > -salary_tol;

                % no profitable deviations found            
                if check_1 == 1 && check_2 == 1
                    % so equilibrium found
                    foundEq = 1;
                % profitable deviations found
                else
                    % so equilibrium not found
                    if disp_opt
                        disp('      Equilibrium not found');
                        disp(' ');
                    end
                    niter = max_iter;
                end
                    
            end

            % display qL cutoff if looking for two-sector equilibrium
            if (eq == 2 || eq == 3) && (niter ~= max_iter ||...
                    foundEq == 1) && disp_opt
                display(['      qL_cutoff = ',num2str(qL_cutoff)])
            end

            % increment iteration counter
            niter = niter + 1;
            if niter == max_iter && disp_opt
                disp('      Equilibrium not found.');
                disp(' ');
            end

        end

        % if equilibrium found, set equilibrium type found, turn off solve 
        % indicator, and display success message
        if foundEq
            foundEq_type = eq;
            solve = 0;
            if disp_opt
                switch foundEq_type
                    case 1, disp('      Single-sector equilibrium found!');
                    case 2, disp('      HH/LL equilibrium found!');
                    case 3, disp('      HL/LH equilibrium found!');
                end
                disp(' ');
            end
            break;
        end
    end

    % if sectors have not been relabeled and no equilibrium has been found,
    % relabel sectors
    if ~foundEq && ~relabel
        relabel = 1;
        if disp_opt
            disp('   Relabeling sectors.')
            disp(' ');
        end
        gam_1_store = gam_1;
        alp_1_store = alp_1;
        bet_1_store = bet_1;
        rho_1_store = rho_1;
        psi_1_store = psi_1;
        p_1_store = p_1;
        gam_1 = gam_2;
        alp_1 = alp_2;
        bet_1 = bet_2;
        rho_1 = rho_2;
        psi_1 = psi_2;
        p_1 = p_2;
        gam_2 = gam_1_store;
        alp_2 = alp_1_store;
        bet_2 = bet_1_store;
        rho_2 = rho_1_store;
        psi_2 = psi_1_store;
        p_2 = p_1_store;
    else
        solve = 0;
    end
    
end

% set qL cutoff, and wage, salary, and matching functions to null if 
% equilibrium not found
if ~foundEq
    qL_cutoff = [];
    wage = [];
    salary = [];
    match = [];
end

% display message if no equilibrium found
if foundEq
    disp('   Equilibrium found.');
    disp(' ');
else
    disp('   No equilibrium found.'); 
    disp(' ');
end

% display ending message
disp('Solver completed.')
disp(' ');

%% SECTION 4: Solve for other statistics of interest

% compute qL cutoff indices
if foundEq_type == 1
    qL_cutoff_index = length(qL_grid);
elseif foundEq_type == 2 || foundEq_type == 3 
    qL_cutoff_index = find(qL_grid==qL_cutoff,1);
elseif foundEq_type == 4 || foundEq_type == 5 || foundEq_type == 6
    qL_cutoff_index(1) = find(qL_grid==qL_cutoff(1),1);
    qL_cutoff_index(2) = find(qL_grid==qL_cutoff(2),1);
else
    qL_cutoff_index = [];
end

% compute qH cutoff
switch foundEq_type
    case 0
        qH_cutoff = [];
    case 1
        qH_cutoff = qH_max;
    case 2
        qH_cutoff = match(qL_cutoff_index);
    case 3
        qH_cutoff = match(1);
    case 4
        qH_cutoff = [match(qL_cutoff_index(1)), match(qL_cutoff_index(2))];
    case 5
        qH_cutoff = [match(qL_cutoff_index(1)), match(end)];
    case 6
        qH_cutoff = [match(1), match(qL_cutoff_index(1))];
        
end

% sort salary function if equilibrium found
if foundEq
    [qH_grid,qH_sort_index] = sort(match);
    salary_sorted = salary(qH_sort_index);
else
    qH_grid = [];
    salary_sorted = [];
end

% compute qH cutoff index
if foundEq_type == 1 || foundEq_type == 2 || foundEq_type == 3
    qH_cutoff_index = find(qH_grid == qH_cutoff,1);
elseif foundEq_type == 4 || foundEq_type == 5 || foundEq_type == 6
    qH_cutoff_index(1) = find(qH_grid == qH_cutoff(1),1);
    qH_cutoff_index(2) = find(qH_grid == qH_cutoff(2),1);
else
   qH_cutoff_index = [];
end

% compute output levels 
if foundEq
    if foundEq_type == 1
        output_1 = computeOutput(gam_1,p_1,qL_grid,wage);
        output_2 = 0;
    elseif foundEq_type == 2 || foundEq_type == 3
        output_1 = computeOutput(gam_1,p_1,qL_grid(qL_grid>=qL_cutoff),...
                    wage(qL_grid>=qL_cutoff));
        output_2 = computeOutput(gam_2,p_2,qL_grid(qL_grid<=qL_cutoff),...
                    wage(qL_grid<=qL_cutoff));
    elseif foundEq_type == 4 || foundEq_type == 5 || foundEq_type == 6
        output_1a = computeOutput(gam_1,p_1,qL_grid(qL_grid<=...
                    qL_cutoff(1)),wage(qL_grid<=qL_cutoff(1)));
        output_1b = computeOutput(gam_1,p_1,qL_grid(qL_grid>=...
                    qL_cutoff(2)),wage(qL_grid>=qL_cutoff(2)));
        output_1 = output_1a + output_1b;
        output_2 = computeOutput(gam_2,p_2,qL_grid(qL_grid>=...
                   qL_cutoff(1) & qL_grid<=qL_cutoff(2)),...
                   wage(qL_grid>=qL_cutoff(1) & qL_grid<=qL_cutoff(2)));
    end
else
    output_1 = [];
    output_2 = [];
end

%% SECTION 5: Store results for output
stats.foundEq = foundEq;
stats.foundEq_type = foundEq_type;
stats.relabel = relabel;
stats.qL_grid = qL_grid;
stats.qH_grid = qH_grid;
stats.wage = wage;
stats.salary = salary;
stats.salary_sorted = salary_sorted;
stats.match = match;
stats.qL_cutoff = qL_cutoff;
stats.qH_cutoff = qH_cutoff;
stats.qL_cutoff_index = qL_cutoff_index;
stats.qH_cutoff_index = qH_cutoff_index;
stats.output_1 = output_1;
stats.output_2 = output_2;

%% SECTION 6: Define functions used by algorithm

% ode functions for bvp4c

% ode for single-sector equilibrium
function dy = odefun_1sec(qL,y)
            dw = y(1)/qL/gam_1*(alp_1*qL^rho_1*(alp_1+bet_1))...
                    /(alp_1*qL^rho_1+bet_1*y(2)^rho_1);
            dm = (L/H)*(phi_L(qL)/phi_H(y(2)))...
                    *(y(1)/(gam_1*p_1*psi_1(y(2),qL)))^(1/(1-gam_1));
            dy = [dw;
                  dm];
end

% ode for two-sector two-region equilibrium
function dy = odefun_2sec_2reg(qL,y,region)
    switch region
        case 1
            dw = y(1)/qL/gam_2*(alp_2*qL^rho_2*(alp_2+bet_2))...
                    /(alp_2*qL^rho_2+bet_2*y(2)^rho_2);
            dm = (L/H)*(phi_L(qL)/phi_H(y(2)))...
                    *(y(1)/(gam_2*p_2*psi_2(y(2),qL)))^(1/(1-gam_2));
            dy = [dw;
                  dm];
        case 2
            dw = y(1)/qL/gam_1*(alp_1*qL^rho_1*(alp_1+bet_1))...
                    /(alp_1*qL^rho_1+bet_1*y(2)^rho_1);
            dm = (L/H)*(phi_L(qL)/phi_H(y(2)))...
                    *(y(1)/(gam_1*p_1*psi_1(y(2),qL)))^(1/(1-gam_1));
            dy = [dw;
                  dm];
    end
end

% ode for two-sector three-region equilibrium
function dy = odefun_2sec_3reg(qL,y,region)
    switch region
        case 1
            dw = y(1)/qL/gam_1*(alp_1*qL^rho_1*(alp_1+bet_1))...
                    /(alp_1*qL^rho_1+bet_1*y(2)^rho_1);
            dm = (L/H)*(phi_L(qL)/phi_H(y(2)))...
                    *(y(1)/(gam_1*p_1*psi_1(y(2),qL)))^(1/(1-gam_1));
            dy = [dw;
                  dm];
        case 2
            dw = y(1)/qL/gam_2*(alp_2*qL^rho_2*(alp_2+bet_2))...
                    /(alp_2*qL^rho_2+bet_2*y(2)^rho_2);
            dm = (L/H)*(phi_L(qL)/phi_H(y(2)))...
                    *(y(1)/(gam_2*p_2*psi_2(y(2),qL)))^(1/(1-gam_2));
            dy = [dw;
                  dm];
        case 3
            dw = y(1)/qL/gam_1*(alp_1*qL^rho_1*(alp_1+bet_1))...
                    /(alp_1*qL^rho_1+bet_1*y(2)^rho_1);
            dm = (L/H)*(phi_L(qL)/phi_H(y(2)))...
                    *(y(1)/(gam_1*p_1*psi_1(y(2),qL)))^(1/(1-gam_1));
            dy = [dw;
                  dm];
    end
end

% boundary conditions for bvp4c

% boundary conditions for one-sector equilibrium
function res = bcfun_1sec(yl,yr)
    res = [yl(2) - qH_min
           yr(2) - qH_max];
end

% boundary conditions for two-sector HH/LL equilibrium
function res = bcfun_2sec_HHLL(yl,yr)
    res = [yl(2,1) - qH_min
           yr(2,2) - qH_max
           yr(1,1) - yl(1,2)
           yr(2,1) - yl(2,2)];
end

% boundary conditions for two-sector HL/LH equilibrium
function res = bcfun_2sec_HLLH(yl,yr)
    res = [yr(2,1) - qH_max
           yl(2,2) - qH_min
           yl(2,1) - yr(2,2)
           yr(1,1) - yl(1,2)];
end

% boundary conditions for two-sector HH/MM/LL equilibrium
function res = bcfun_2sec_HHMMLL(yl,yr)
    res = [yl(2,1) - qH_min
           yr(2,3) - qH_max
           yr(2,1) - yl(2,2)
           yr(2,2) - yl(2,3)
           yr(1,1) - yl(1,2)
           yr(1,2) - yl(1,3)];
end

% boundary conditions for two-sector HM/MH/LL equilibrium
function res = bcfun_2sec_HMMHLL(yl,yr)
    res = [yl(2,1) - qH_min
           yr(2,2) - qH_max
           yr(2,1) - yl(2,3)
           yl(2,2) - yr(2,3)
           yr(1,1) - yl(1,2)
           yr(1,2) - yl(1,3)];
end

% boundary conditions for two-sector HH/ML/LMequilibrium
function res = bcfun_2sec_HHMLLM(yl,yr)
    res = [yl(2,2) - qH_min
           yr(2,3) - qH_max
           yl(2,1) - yr(2,2)
           yr(2,1) - yl(2,3)
           yr(1,1) - yl(1,2)
           yr(1,2) - yl(1,3)];
end

% initial guess for bvp4c

% initial guess for one-sector equilibrium
function y = yinit_1sec(qL)
    wrange_min = init_wage;
    wrange_max = wrange_min + (qL_max-qL_min);
    y = [wrange_min+(wrange_max-wrange_min)/(qL_max-qL_min)*(qL-qL_min);
             qH_min + (qH_max-qH_min)/(qL_cutoff-qL_min)*(qL-qL_min)];
end

% initial guess for two-sector HH/LL equilibrium
function y = yinit_2sec_HHLL(qL,region)
    wrange_min = init_wage;
    wrange_max = wrange_min + (qL_max-qL_min);
    wrange_mid = (wrange_max+wrange_min)/2;
    qH_mid = qH_min + (qH_max-qH_min)/2;
    switch region
        case 1
            y = [wrange_min+(wrange_mid-wrange_min)/(qL_cutoff-qL_min)*...
                (qL-qL_min); qH_min+(qH_mid-qH_min)/(qL_cutoff-qL_min)*...
                (qL-qL_min)];
        case 2
            y = [wrange_mid+(wrange_max-wrange_mid)/(qL_max-qL_cutoff)*...
                (qL-qL_cutoff); qH_mid+(qH_max-qH_mid)/(qL_max-...
                qL_cutoff)*(qL-qL_cutoff)];
    end
end

% initial guess for two-sector HL/LH equilibrium
function y = yinit_2sec_HLLH(qL,region)
    wrange_min = init_wage;
    wrange_max = wrange_min + (qL_max-qL_min);
    wrange_mid = (wrange_max+wrange_min)/2;
    qH_mid = qH_min + (qH_max-qH_min)/2;
    switch region
        case 1
            y = [wrange_min+(wrange_mid-wrange_min)/(qL_cutoff-...
                qL_min)*(qL-qL_min); qH_mid+(qH_max-qH_mid)/(qL_cutoff-...
                qL_min)*(qL-qL_min)];
        case 2
            y = [wrange_mid+(wrange_max-wrange_mid)/(qL_max-qL_cutoff)*...
                (qL-qL_cutoff); qH_min+(qH_mid-qH_min)/(qL_max-...
                qL_cutoff)*(qL-qL_cutoff)];
    end
end

% initial guess for two-sector HH/MM/LL equilibrium
function y = yinit_2sec_HHMMLL(qL,region)
    wrange_min = init_wage;
    wrange_max = wrange_min + (qL_max-qL_min);
    wrange_third = wrange_min + (wrange_max-wrange_min)/3;
    qH_third = qH_min + (qH_max-qH_min)/3;
    switch region
        case 1
            y = [wrange_min+(wrange_third-wrange_min)/(qL_cutoff(1)-...
                qL_min)*(qL-qL_min); qH_min+(qH_third-qH_min)/...
                (qL_cutoff(1)-qL_min)*(qL-qL_min)];
        case 2
            y = [wrange_third+(2*wrange_third-wrange_third)/...
                (qL_cutoff(2)-qL_cutoff(1))*(qL-qL_cutoff(1));
                qH_third+(2*qH_third-qH_third)/(qL_cutoff(2)-...
                qL_cutoff(1))*(qL-qL_cutoff(1))];
        case 3
            y = [2*wrange_third+(wrange_max-2*wrange_third)/(qL_max-...
                qL_cutoff(2))*(qL-qL_cutoff(2)); 2*qH_third+(qH_max-...
                2*qH_third)/(qL_max-qL_cutoff(2))*(qL-qL_cutoff(2))];
    end
end

% initial guess for two-sector HM/MH/LL equilibrium
function y = yinit_2sec_HMMHLL(qL,region)
    wrange_min = init_wage;
    wrange_max = wrange_min + (qL_max-qL_min);
    wrange_third = wrange_min + (wrange_max-wrange_min)/3;
    qH_third = qH_min + (qH_max-qH_min)/3;
    switch region
        case 1
            y = [wrange_min+(wrange_third-wrange_min)/(qL_cutoff(1)-...
                qL_min)*(qL-qL_min); qH_min+(qH_third-qH_min)/...
                (qL_cutoff(1)-qL_min)*(qL-qL_min)];
        case 2
            y = [wrange_third+(2*wrange_third-wrange_third)/...
                (qL_cutoff(2)-qL_cutoff(1))*(qL-qL_cutoff(1));
                2*qH_third+(qH_max-2*qH_third)/(qL_cutoff(2)-...
                qL_cutoff(1))*(qL-qL_cutoff(1))];
        case 3
            y = [2*wrange_third+(wrange_max-2*wrange_third)/(qL_max-...
                qL_cutoff(2))*(qL-qL_cutoff(2)); qH_third+(2*qH_third-...
                qH_third)/(qL_max-qL_cutoff(2))*(qL-qL_cutoff(2))];
    end
end

% initial guess for two-sector HH/ML/LM equilibrium
function y = yinit_2sec_HHMLLM(qL,region)
    wrange_min = init_wage;
    wrange_max = wrange_min + (qL_max-qL_min);
    wrange_third = wrange_min + (wrange_max-wrange_min)/3;
    qH_third = qH_min + (qH_max-qH_min)/3;
    switch region
        case 1
            y = [wrange_min+(wrange_third-wrange_min)/(qL_cutoff(1)-...
                qL_min)*(qL-qL_min); qH_third+(2*qH_third-qH_third)/...
                (qL_cutoff(1)-qL_min)*(qL-qL_min)];
        case 2
            y = [wrange_third+(2*wrange_third-wrange_third)/...
                (qL_cutoff(2)-qL_cutoff(1))*(qL-qL_cutoff(1));qH_min+...
                (qH_third-qH_min)/(qL_cutoff(2)-qL_cutoff(1))...
                *(qL-qL_cutoff(1))];
        case 3
            y = [2*wrange_third+(wrange_max-2*wrange_third)/(qL_max-...
                qL_cutoff(2))*(qL-qL_cutoff(2)); 2*qH_third+(qH_max-2*...
                qH_third)/(qL_max-qL_cutoff(2))*(qL-qL_cutoff(2))];
    end
end

% salary, shadow match, and output functions

% salary function
function salary = computeSalary(gamma,p,psi,qL_grid,w,m)
    gammaBar = gamma^(gamma/(1-gamma))-gamma^(1/(1-gamma));
    salary = gammaBar*p^(1/(1-gamma))*(psi(m,qL_grid)).^(1/(1-gamma))...
                .*(w.^(-gamma/(1-gamma)));
end

% shadow match function
function [m_inv_shadow,m_inv_shadow_ind] = ...
    computeShadowMatch(gamma_shadow,psi_shadow,qL_grid,w,m)

    % Initialize inverse match function in shadow sector
    m_inv_shadow = nan(length(qL_grid),1);
    m_inv_shadow_ind = nan(length(qL_grid),1);

    % Iterate over m(qL_grid) values, finding optimal match for each
    for i=1:length(qL_grid)
        [~,optimal_qL] = max(psi_shadow(m(i),qL_grid).*w.^(-gamma_shadow));
        m_inv_shadow_ind(i) = optimal_qL;
        m_inv_shadow(i) = qL_grid(optimal_qL);

    end
end

% output function
function output = computeOutput(gamma,p,qL_grid,w)
    output = (L/(gamma*p))*trapz(qL_grid,...
                        w.*phi_L(qL_grid),1);
end

end