% Title: GHK_figures.m
% Date: 5/21/2015
% Author: Kevin Lim
% Description: 
%   This file contains code to reproduce all figures in the online appendix
%   to GHK (which includes figures 4, 5, and 7 of the main text). The code 
%   uses the algorithm implemented in GHK_algorithm.m to solve for the 
%   equilibrium matching, wage, and salary functions. When used to study
%   comparative statics, the script uses the function GHK_intpol.m to 
%   interpolate wage and salary solutions over a fixed grid. To generate a 
%   specific figure, set the variable figure_mode to the relevant string.

clear all; close all; clc

% Set mode: to generate figure, uncomment relevant line
figure_mode = 'figure 1';
%figure_mode = 'figure 2';
%figure_mode = 'figure 3';
%figure_mode = 'figure 4';
%figure_mode = 'figure 5';
%figure_mode = 'figure 6';
%figure_mode = 'figure 7';
%figure_mode = 'figure 8';
%figure_mode = 'figure 9';
%figure_mode = 'figure 10';
%figure_mode = 'figure 11';
%figure_mode = 'figure 12';
%figure_mode = 'figure 13';
%figure_mode = 'figure 14';

% plotting options
fsize = 26;         % font size
lwidth = [2 4 6];   % sequence of plot line widths
awidth = 2.5;       % axis line width

switch figure_mode
    
    % Figure 1: 
    %   Example of matching, wage, and salary functions in an equilibrium 
    %   with three regions of sorting
    
    case 'figure 1'
        
        % set sector-specific parameters
        sec.gam_1 = .6;
        sec.gam_2 = .4;
        sec.alp_1 = .2;
        sec.alp_2 = .3;
        sec.bet_1 = 1-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -1;
        sec.rho_2 = -5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 1.1;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                    /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                    /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = 6;
        sol.init_wage = .5;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-4;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;
        sol.qL_cutoff_manual = [1.1577, 1.5115];

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);
        qL_grid = stats.qL_grid;
        qH_grid = stats.qH_grid;
        qL_cutoff = stats.qL_cutoff;
        qH_cutoff = stats.qH_cutoff;
        match = stats.match;
        wage = stats.wage;
        salary_sorted = stats.salary_sorted;
        
        % plot matching function
        figure(); hold on;
        index = qL_grid<qL_cutoff(1);
        p1 = plot(qL_grid(index),match(index),'Color','b',...
            'LineWidth',lwidth(1));
        index = qL_grid>qL_cutoff(2);
        plot(qL_grid(index),match(index),'Color','b',...
            'LineWidth',lwidth(1));
        index = qL_grid>qL_cutoff(1) & qL_grid<qL_cutoff(2);
        p2 = plot(qL_grid(index),match(index),'Color','r',...
            'LineWidth',lwidth(2));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('q_H','FontSize',fsize);
        title('Matching function','FontSize',fsize);
        mplot_leg = legend([p1 p2],'Sector 1','Sector 2');
        set(mplot_leg,'Location','SouthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot wage function
        figure(); hold on;
        index = qL_grid<=qL_cutoff(1);
        p1 = plot(qL_grid(index),wage(index),'Color','b',...
            'LineWidth',lwidth(1));
        index = qL_grid>=qL_cutoff(2);
        plot(qL_grid(index),wage(index),'Color','b',...
            'LineWidth',lwidth(1));
        index = qL_grid>=qL_cutoff(1) & qL_grid<=qL_cutoff(2);
        p2 = plot(qL_grid(index),wage(index),'Color','r',...
            'LineWidth',lwidth(2));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('w(q_L)','FontSize',fsize);
        title('Wage function','FontSize',fsize);
        wplot_leg = legend([p1 p2],'Sector 1','Sector 2');
        set(wplot_leg,'Location','SouthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot salary function
        figure(); hold on;
        index = qH_grid>=qH_cutoff(1);
        p1 = plot(qH_grid(index),salary_sorted(index),'Color','b',...
             'LineWidth',lwidth(1));
        index = qH_grid<=qH_cutoff(1);
        p2 = plot(qH_grid(index),salary_sorted(index),'Color','r',...
             'LineWidth',lwidth(2));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('r(q_H)','FontSize',fsize);
        title('Salary function','FontSize',fsize);
        rplot_leg = legend([p1 p2],'Sector 1','Sector 2');
        set(rplot_leg,'Location','SouthEast');
        set(gca,'FontSize',fsize,'Xlim',[fac.qH_min fac.qH_max]);
        set(gca,'LineWidth',awidth);
    
    % Figure 2: 
    %   (GHK Figure 4) Effects of a 10% increase in p_2 on wages and 
    %   salaries in an HH/LL equilibrium without Stolper-Samuelson forces    
        
    case 'figure 2'
        
        % set sector-specific parameters
        sec.gam_1 = .1;
        sec.gam_2 = .1;
        sec.alp_1 = 1;
        sec.alp_2 = .5;
        sec.bet_1 = 2-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -5;
        sec.rho_2 = -5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 2;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                    /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                    /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = [1 2 3];
        sol.init_wage = .01;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-5;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);

        % increase p_2 by 10% and solve for new equlibrium
        param_cs = param;
        param_cs.sec.p_2 = param.sec.p_2 * 1.1;
        stats_cs = GHK_algorithm(param_cs);

        % interpolate wage solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of wages)
        base.grid = stats.qL_grid;
        base.values = stats.wage;
        base.cutoff = stats.qL_cutoff;
        cs.grid = stats_cs.qL_grid;
        cs.values = stats_cs.wage;
        cs.cutoff = stats_cs.qL_cutoff;
        [wage_grid,~,~,wage_pct] = GHK_intpol(base,cs);

        % interpolate salary solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of salaries)
        base.grid = stats.qH_grid;
        base.values = stats.salary_sorted;
        base.cutoff = stats.qH_cutoff;
        cs.grid = stats_cs.qH_grid;
        cs.values = stats_cs.salary_sorted;
        cs.cutoff = stats_cs.qH_cutoff;
        [salary_grid,~,~,salary_pct] = GHK_intpol(base,cs);

        % plot percentage change in wages
        figure(); hold on;
        plot(wage_grid.high,wage_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(wage_grid.switch,wage_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(wage_grid.low,wage_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        plot(get(gca,'Xlim'),[0 0],'Color','k','LineStyle',':',...
             'LineWidth',lwidth(2));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('% change in w(q_L)','FontSize',fsize);
        wplot_leg = legend('Workers originally in sector 1',...
                       'Workers switching from sector 1 to sector 2',...
                       'Workers originally in sector 2');
        set(wplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth)
        axis([1 2 -10 30]);
        
        % plot percentage change in salaries
        figure(); hold on;
        plot(salary_grid.high,salary_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(salary_grid.switch,salary_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(salary_grid.low,salary_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('% change in r(q_H)','FontSize',fsize);
        rplot_leg = legend('Managers originally in sector 1',...
                         'Managers switching from sector 1 to sector 2',...
                         'Managers originally in sector 2');
        set(rplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth)
    
    % Figure 3: 
    %   (GHK Figure 5) Effects of a 10% increase in p_2 on wages and 
    %   salaries in an HH/LL equilibrium with opposite shifts in sectoral 
    %   matching functions and moderate Stolper-Samuelson forces
    
    case 'figure 3'

        % set sector-specific parameters
        sec.gam_1 = .4;
        sec.gam_2 = .6;
        sec.alp_1 = 1;
        sec.alp_2 = .5;
        sec.bet_1 = 2-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -5;
        sec.rho_2 = -5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 2;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = [1 2 3];
        sol.init_wage = .01;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-5;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);

        % increase p_2 by 10% and solve for new equlibrium
        param_cs = param;
        param_cs.sec.p_2 = param.sec.p_2 * 1.1;
        stats_cs = GHK_algorithm(param_cs);

        % interpolate wage solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of wages)
        base.grid = stats.qL_grid;
        base.values = stats.wage;
        base.cutoff = stats.qL_cutoff;
        cs.grid = stats_cs.qL_grid;
        cs.values = stats_cs.wage;
        cs.cutoff = stats_cs.qL_cutoff;
        [wage_grid,~,~,wage_pct] = GHK_intpol(base,cs);

        % interpolate salary solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of salaries)
        base.grid = stats.qH_grid;
        base.values = stats.salary_sorted;
        base.cutoff = stats.qH_cutoff;
        cs.grid = stats_cs.qH_grid;
        cs.values = stats_cs.salary_sorted;
        cs.cutoff = stats_cs.qH_cutoff;
        [salary_grid,~,~,salary_pct] = GHK_intpol(base,cs);

        % plot percentage change in wages
        figure(); hold on;
        plot(wage_grid.high,wage_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(wage_grid.switch,wage_pct.switch,'Color','m',...
            'LineStyle','--','LineWidth',lwidth(2));
        plot(wage_grid.low,wage_pct.low,'Color','r','LineWidth',lwidth(3));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('% change in w(q_L)','FontSize',fsize);
        wplot_leg = legend('Workers originally in sector 1',...
                       'Workers switching from sector 1 to sector 2',...
                       'Workers originally in sector 2');
        set(wplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth)
        
        % plot percentage change in salaries
        figure(); hold on;
        plot(salary_grid.high,salary_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(salary_grid.switch,salary_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(salary_grid.low,salary_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        plot(get(gca,'Xlim'),[0 0],'Color','k','LineStyle',':',...
             'LineWidth',lwidth(2));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('% change in r(q_H)','FontSize',fsize);
        rplot_leg = legend('Managers originally in sector 1',...
                         'Managers switching from sector 1 to sector 2',...
                         'Managers originally in sector 2');
        set(rplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth)
    
    % Figure 4: 
    %   (GHK Figure 7) Effects of a 10% increase in p_2 on wages and 
    %   salaries in an HL/LH without Stolper-Samuelson forces
    case 'figure 4'

        % set sector-specific parameters
        sec.gam_1 = .5;
        sec.gam_2 = .5;
        sec.alp_1 = .6;
        sec.alp_2 = .4;
        sec.bet_1 = 1-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -.5;
        sec.rho_2 = -.5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 2;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = [1 2 3];
        sol.init_wage = .01;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-5;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);

        % increase p_2 by 10% and solve for new equlibrium
        param_cs = param;
        param_cs.sec.p_2 = param.sec.p_2 * 1.1;
        stats_cs = GHK_algorithm(param_cs);

        % interpolate wage solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of wages)
        base.grid = stats.qL_grid;
        base.values = stats.wage;
        base.cutoff = stats.qL_cutoff;
        cs.grid = stats_cs.qL_grid;
        cs.values = stats_cs.wage;
        cs.cutoff = stats_cs.qL_cutoff;
        [wage_grid,~,~,wage_pct] = GHK_intpol(base,cs);

        % interpolate salary solutions for both baseline and comparative
        % static cases over a common grid (to allow comparison of salaries)
        base.grid = stats.qH_grid;
        base.values = stats.salary_sorted;
        base.cutoff = stats.qH_cutoff;
        cs.grid = stats_cs.qH_grid;
        cs.values = stats_cs.salary_sorted;
        cs.cutoff = stats_cs.qH_cutoff;
        [salary_grid,~,~,salary_pct] = GHK_intpol(base,cs);

        % plot percentage change in wages
        figure(); hold on;
        plot(wage_grid.high,wage_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(wage_grid.switch,wage_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(wage_grid.low,wage_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        plot(get(gca,'Xlim'),[0 0],'Color','k','LineStyle',':',...
             'LineWidth',lwidth(2));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('% change in w(q_L)','FontSize',fsize);
        wplot_leg = legend('Workers originally in sector 1',...
                       'Workers switching from sector 1 to sector 2',...
                       'Workers originally in sector 2');
        set(wplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot percentage change in salaries
        figure(); hold on;
        plot(salary_grid.low,salary_pct.low,'Color','b',...
            'LineWidth',lwidth(1));
        plot(salary_grid.switch,salary_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(salary_grid.high,salary_pct.high,'Color','r',...
            'LineWidth',lwidth(3));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('% change in r(q_H)','FontSize',fsize);
        rplot_leg = legend('Managers originally in sector 1',...
                         'Managers switching from sector 1 to sector 2',...
                         'Managers originally in sector 2');
        set(rplot_leg,'Location','NorthWest');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);    
        
    % Figure 5: 
    %   Response of matching, wage, and salary functions for case 1, HH/LL
    %   equilibria
    case 'figure 5'

        % set sector-specific parameters
        sec.gam_1 = .5;
        sec.gam_2 = .5;
        sec.alp_1 = 1;
        sec.alp_2 = .5;
        sec.bet_1 = 2-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -5;
        sec.rho_2 = -5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 2;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = [1 2 3];
        sol.init_wage = .01;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-5;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);

        % increase p_2 by 10% and solve for new equlibrium
        p_2_mul = 1.1;
        param_cs = param;
        param_cs.sec.p_2 = param.sec.p_2 * p_2_mul;
        stats_cs = GHK_algorithm(param_cs);

        % interpolate wage solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of wages)
        base.grid = stats.qL_grid;
        base.values = stats.wage;
        base.cutoff = stats.qL_cutoff;
        cs.grid = stats_cs.qL_grid;
        cs.values = stats_cs.wage;
        cs.cutoff = stats_cs.qL_cutoff;
        [wage_grid,~,~,wage_pct] = GHK_intpol(base,cs);

        % interpolate salary solutions for both baseline and comparative
        % static cases over a common grid (to allow comparison of salaries)
        base.grid = stats.qH_grid;
        base.values = stats.salary_sorted;
        base.cutoff = stats.qH_cutoff;
        cs.grid = stats_cs.qH_grid;
        cs.values = stats_cs.salary_sorted;
        cs.cutoff = stats_cs.qH_cutoff;
        [salary_grid,~,~,salary_pct] = GHK_intpol(base,cs);

        % plot matching function
        figure(); hold on;
        plot(stats.qL_grid(stats.qL_cutoff_index+1:end),...
             stats.match(stats.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1));
        plot(stats.qL_grid(1:stats.qL_cutoff_index),...
             stats.match(1:stats.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2));
        plot(stats_cs.qL_grid(stats_cs.qL_cutoff_index+1:end),...
             stats_cs.match(stats_cs.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1),'LineStyle','--');
        plot(stats_cs.qL_grid(1:stats_cs.qL_cutoff_index),...
             stats_cs.match(1:stats_cs.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2),'LineStyle','--');
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('q_H','FontSize',fsize);
        mplot_leg = legend('Sector 1: baseline','Sector 2: baseline',...
                    ['Sector 1: +' num2str((p_2_mul-1)*100) '% p_2'],...
                    ['Sector 2: +' num2str((p_2_mul-1)*100) '% p_2']);
        set(mplot_leg,'Location','SouthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot percentage change in wages
        figure(); hold on;
        plot(wage_grid.high,wage_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(wage_grid.switch,wage_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(wage_grid.low,wage_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        plot(get(gca,'Xlim'),[0 0],'Color','k','LineStyle',':',...
             'LineWidth',lwidth(2));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('% change in w(q_L)','FontSize',fsize);
        wplot_leg = legend('Workers originally in sector 1',...
                       'Workers switching from sector 1 to sector 2',...
                       'Workers originally in sector 2');
        set(wplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);

        % plot percentage change in salaries
        figure(); hold on;
        plot(salary_grid.high,salary_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(salary_grid.switch,salary_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(salary_grid.low,salary_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        plot(get(gca,'Xlim'),[0 0],'Color','k','LineStyle',':',...
             'LineWidth',lwidth(2));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('% change in r(q_H)','FontSize',fsize);
        rplot_leg = legend('Managers originally in sector 1',...
                         'Managers switching from sector 1 to sector 2',...
                         'Managers originally in sector 2');
        set(rplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
    % Figure 6: 
    %   Response of matching, wage, and salary functions for case 2, HH/LL
    %   equilibria
    case 'figure 6'

        % set sector-specific parameters
        sec.gam_1 = .1;
        sec.gam_2 = .1;
        sec.alp_1 = 1;
        sec.alp_2 = .5;
        sec.bet_1 = 2-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -5;
        sec.rho_2 = -5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 2;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = [1 2 3];
        sol.init_wage = .01;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-5;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);

        % increase p_2 by 10% and solve for new equlibrium
        p_2_mul = 1.1;
        param_cs = param;
        param_cs.sec.p_2 = param.sec.p_2 * p_2_mul;
        stats_cs = GHK_algorithm(param_cs);

        % interpolate wage solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of wages)
        base.grid = stats.qL_grid;
        base.values = stats.wage;
        base.cutoff = stats.qL_cutoff;
        cs.grid = stats_cs.qL_grid;
        cs.values = stats_cs.wage;
        cs.cutoff = stats_cs.qL_cutoff;
        [wage_grid,~,~,wage_pct] = GHK_intpol(base,cs);

        % interpolate salary solutions for both baseline and comparative
        % static cases over a common grid (to allow comparison of salaries)
        base.grid = stats.qH_grid;
        base.values = stats.salary_sorted;
        base.cutoff = stats.qH_cutoff;
        cs.grid = stats_cs.qH_grid;
        cs.values = stats_cs.salary_sorted;
        cs.cutoff = stats_cs.qH_cutoff;
        [salary_grid,~,~,salary_pct] = GHK_intpol(base,cs);

        % plot matching function
        figure(); hold on;
        plot(stats.qL_grid(stats.qL_cutoff_index+1:end),...
             stats.match(stats.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1));
        plot(stats.qL_grid(1:stats.qL_cutoff_index),...
             stats.match(1:stats.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2));
        plot(stats_cs.qL_grid(stats_cs.qL_cutoff_index+1:end),...
             stats_cs.match(stats_cs.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1),'LineStyle','--');
        plot(stats_cs.qL_grid(1:stats_cs.qL_cutoff_index),...
             stats_cs.match(1:stats_cs.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2),'LineStyle','--');
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('q_H','FontSize',fsize);
        mplot_leg = legend('Sector 1: baseline','Sector 2: baseline',...
                    ['Sector 1: +' num2str((p_2_mul-1)*100) '% p_2'],...
                    ['Sector 2: +' num2str((p_2_mul-1)*100) '% p_2']);
        set(mplot_leg,'Location','SouthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot percentage change in wages
        figure(); hold on;
        plot(wage_grid.high,wage_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(wage_grid.switch,wage_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(wage_grid.low,wage_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        plot(get(gca,'Xlim'),[0 0],'Color','k','LineStyle',':',...
             'LineWidth',lwidth(2));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('% change in w(q_L)','FontSize',fsize);
        wplot_leg = legend('Workers originally in sector 1',...
                       'Workers switching from sector 1 to sector 2',...
                       'Workers originally in sector 2');
        set(wplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        axis([1 2 -10 30]);

        % plot percentage change in salaries
        figure(); hold on;
        plot(salary_grid.high,salary_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(salary_grid.switch,salary_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(salary_grid.low,salary_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('% change in r(q_H)','FontSize',fsize);
        rplot_leg = legend('Managers originally in sector 1',...
                         'Managers switching from sector 1 to sector 2',...
                         'Managers originally in sector 2');
        set(rplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
    % Figure 7: 
    %   Response of matching, wage, and salary functions for case 3, HH/LL
    %   equilibria
    case 'figure 7'

        % set sector-specific parameters
        sec.gam_1 = .9;
        sec.gam_2 = .9;
        sec.alp_1 = 1;
        sec.alp_2 = .5;
        sec.bet_1 = 2-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -5;
        sec.rho_2 = -5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 2;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = [1 2 3];
        sol.init_wage = 1;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-5;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);

        % increase p_2 by 10% and solve for new equlibrium
        p_2_mul = 1.1;
        param_cs = param;
        param_cs.sec.p_2 = param.sec.p_2 * p_2_mul;
        stats_cs = GHK_algorithm(param_cs);

        % interpolate wage solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of wages)
        base.grid = stats.qL_grid;
        base.values = stats.wage;
        base.cutoff = stats.qL_cutoff;
        cs.grid = stats_cs.qL_grid;
        cs.values = stats_cs.wage;
        cs.cutoff = stats_cs.qL_cutoff;
        [wage_grid,~,~,wage_pct] = GHK_intpol(base,cs);

        % interpolate salary solutions for both baseline and comparative
        % static cases over a common grid (to allow comparison of salaries)
        base.grid = stats.qH_grid;
        base.values = stats.salary_sorted;
        base.cutoff = stats.qH_cutoff;
        cs.grid = stats_cs.qH_grid;
        cs.values = stats_cs.salary_sorted;
        cs.cutoff = stats_cs.qH_cutoff;
        [salary_grid,~,~,salary_pct] = GHK_intpol(base,cs);

        % plot matching function
        figure(); hold on;
        plot(stats.qL_grid(stats.qL_cutoff_index+1:end),...
             stats.match(stats.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1));
        plot(stats.qL_grid(1:stats.qL_cutoff_index),...
             stats.match(1:stats.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2));
        plot(stats_cs.qL_grid(stats_cs.qL_cutoff_index+1:end),...
             stats_cs.match(stats_cs.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1),'LineStyle','--');
        plot(stats_cs.qL_grid(1:stats_cs.qL_cutoff_index),...
             stats_cs.match(1:stats_cs.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2),'LineStyle','--');
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('q_H','FontSize',fsize);
        mplot_leg = legend('Sector 1: baseline','Sector 2: baseline',...
                    ['Sector 1: +' num2str((p_2_mul-1)*100) '% p_2'],...
                    ['Sector 2: +' num2str((p_2_mul-1)*100) '% p_2']);
        set(mplot_leg,'Location','SouthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot percentage change in wages
        figure(); hold on;
        plot(wage_grid.high,wage_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(wage_grid.switch,wage_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(wage_grid.low,wage_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('% change in w(q_L)','FontSize',fsize);
        wplot_leg = legend('Workers originally in sector 1',...
                       'Workers switching from sector 1 to sector 2',...
                       'Workers originally in sector 2');
        set(wplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);

        % plot percentage change in salaries
        figure(); hold on;
        plot(salary_grid.high,salary_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(salary_grid.switch,salary_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(salary_grid.low,salary_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        plot(get(gca,'Xlim'),[0 0],'Color','k','LineStyle',':',...
             'LineWidth',lwidth(2));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('% change in r(q_H)','FontSize',fsize);
        rplot_leg = legend('Managers originally in sector 1',...
                         'Managers switching from sector 1 to sector 2',...
                         'Managers originally in sector 2');
        set(rplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);   
        axis([1 2 -10 30]);

    % Figure 8: 
    %   Response of matching, wage, and salary functions for case 4, HH/LL
    %   equilibria
    case 'figure 8'

        % set sector-specific parameters
        sec.gam_1 = .4;
        sec.gam_2 = .6;
        sec.alp_1 = 1;
        sec.alp_2 = .5;
        sec.bet_1 = 2-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -5;
        sec.rho_2 = -5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 2;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = [1 2 3];
        sol.init_wage = 1;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-5;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);

        % increase p_2 by 10% and solve for new equlibrium
        p_2_mul = 1.1;
        param_cs = param;
        param_cs.sec.p_2 = param.sec.p_2 * p_2_mul;
        stats_cs = GHK_algorithm(param_cs);

        % interpolate wage solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of wages)
        base.grid = stats.qL_grid;
        base.values = stats.wage;
        base.cutoff = stats.qL_cutoff;
        cs.grid = stats_cs.qL_grid;
        cs.values = stats_cs.wage;
        cs.cutoff = stats_cs.qL_cutoff;
        [wage_grid,~,~,wage_pct] = GHK_intpol(base,cs);

        % interpolate salary solutions for both baseline and comparative
        % static cases over a common grid (to allow comparison of salaries)
        base.grid = stats.qH_grid;
        base.values = stats.salary_sorted;
        base.cutoff = stats.qH_cutoff;
        cs.grid = stats_cs.qH_grid;
        cs.values = stats_cs.salary_sorted;
        cs.cutoff = stats_cs.qH_cutoff;
        [salary_grid,~,~,salary_pct] = GHK_intpol(base,cs);

        % plot matching function
        figure(); hold on;
        plot(stats.qL_grid(stats.qL_cutoff_index+1:end),...
             stats.match(stats.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1));
        plot(stats.qL_grid(1:stats.qL_cutoff_index),...
             stats.match(1:stats.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2));
        plot(stats_cs.qL_grid(stats_cs.qL_cutoff_index+1:end),...
             stats_cs.match(stats_cs.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1),'LineStyle','--');
        plot(stats_cs.qL_grid(1:stats_cs.qL_cutoff_index),...
             stats_cs.match(1:stats_cs.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2),'LineStyle','--');
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('q_H','FontSize',fsize);
        mplot_leg = legend('Sector 1: baseline','Sector 2: baseline',...
                    ['Sector 1: +' num2str((p_2_mul-1)*100) '% p_2'],...
                    ['Sector 2: +' num2str((p_2_mul-1)*100) '% p_2']);
        set(mplot_leg,'Location','SouthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot percentage change in wages
        figure(); hold on;
        plot(wage_grid.high,wage_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(wage_grid.switch,wage_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(wage_grid.low,wage_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('% change in w(q_L)','FontSize',fsize);
        wplot_leg = legend('Workers originally in sector 1',...
                       'Workers switching from sector 1 to sector 2',...
                       'Workers originally in sector 2');
        set(wplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);

        % plot percentage change in salaries
        figure(); hold on;
        plot(salary_grid.high,salary_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(salary_grid.switch,salary_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(salary_grid.low,salary_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        plot(get(gca,'Xlim'),[0 0],'Color','k','LineStyle',':',...
             'LineWidth',lwidth(2));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('% change in r(q_H)','FontSize',fsize);
        rplot_leg = legend('Managers originally in sector 1',...
                         'Managers switching from sector 1 to sector 2',...
                         'Managers originally in sector 2');
        set(rplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);  
        
    % Figure 9: 
    %   Response of matching, wage, and salary functions for case 5, HH/LL
    %   equilibria
    case 'figure 9'

        % set sector-specific parameters
        sec.gam_1 = .6;
        sec.gam_2 = .4;
        sec.alp_1 = 1;
        sec.alp_2 = .5;
        sec.bet_1 = 2-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -5;
        sec.rho_2 = -5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 2;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = [1 2 3];
        sol.init_wage = 1;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-5;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);

        % increase p_2 by 10% and solve for new equlibrium
        p_2_mul = 1.1;
        param_cs = param;
        param_cs.sec.p_2 = param.sec.p_2 * p_2_mul;
        stats_cs = GHK_algorithm(param_cs);

        % interpolate wage solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of wages)
        base.grid = stats.qL_grid;
        base.values = stats.wage;
        base.cutoff = stats.qL_cutoff;
        cs.grid = stats_cs.qL_grid;
        cs.values = stats_cs.wage;
        cs.cutoff = stats_cs.qL_cutoff;
        [wage_grid,~,~,wage_pct] = GHK_intpol(base,cs);

        % interpolate salary solutions for both baseline and comparative
        % static cases over a common grid (to allow comparison of salaries)
        base.grid = stats.qH_grid;
        base.values = stats.salary_sorted;
        base.cutoff = stats.qH_cutoff;
        cs.grid = stats_cs.qH_grid;
        cs.values = stats_cs.salary_sorted;
        cs.cutoff = stats_cs.qH_cutoff;
        [salary_grid,~,~,salary_pct] = GHK_intpol(base,cs);

        % plot matching function
        figure(); hold on;
        plot(stats.qL_grid(stats.qL_cutoff_index+1:end),...
             stats.match(stats.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1));
        plot(stats.qL_grid(1:stats.qL_cutoff_index),...
             stats.match(1:stats.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2));
        plot(stats_cs.qL_grid(stats_cs.qL_cutoff_index+1:end),...
             stats_cs.match(stats_cs.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1),'LineStyle','--');
        plot(stats_cs.qL_grid(1:stats_cs.qL_cutoff_index),...
             stats_cs.match(1:stats_cs.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2),'LineStyle','--');
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('q_H','FontSize',fsize);
        mplot_leg = legend('Sector 1: baseline','Sector 2: baseline',...
                    ['Sector 1: +' num2str((p_2_mul-1)*100) '% p_2'],...
                    ['Sector 2: +' num2str((p_2_mul-1)*100) '% p_2']);
        set(mplot_leg,'Location','SouthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot percentage change in wages
        figure(); hold on;
        plot(wage_grid.high,wage_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(wage_grid.switch,wage_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(wage_grid.low,wage_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        plot(get(gca,'Xlim'),[0 0],'Color','k','LineStyle',':',...
             'LineWidth',lwidth(2));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('% change in w(q_L)','FontSize',fsize);
        wplot_leg = legend('Workers originally in sector 1',...
                       'Workers switching from sector 1 to sector 2',...
                       'Workers originally in sector 2');
        set(wplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);

        % plot percentage change in salaries
        figure(); hold on;
        plot(salary_grid.high,salary_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(salary_grid.switch,salary_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(salary_grid.low,salary_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('% change in r(q_H)','FontSize',fsize);
        rplot_leg = legend('Managers originally in sector 1',...
                         'Managers switching from sector 1 to sector 2',...
                         'Managers originally in sector 2');
        set(rplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        axis([1 2 2 20]);
        
    % Figure 10: 
    %   Response of matching, wage, and salary functions for case 1, HL/LH
    %   equilibria
    case 'figure 10'

        % set sector-specific parameters
        sec.gam_1 = .5;
        sec.gam_2 = .5;
        sec.alp_1 = .6;
        sec.alp_2 = .4;
        sec.bet_1 = 1-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -.5;
        sec.rho_2 = -.5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 2;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = [1 2 3];
        sol.init_wage = 1;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-5;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);

        % increase p_2 by 5% and solve for new equlibrium
        p_2_mul = 1.05;
        param_cs = param;
        param_cs.sec.p_2 = param.sec.p_2 * p_2_mul;
        stats_cs = GHK_algorithm(param_cs);

        % interpolate wage solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of wages)
        base.grid = stats.qL_grid;
        base.values = stats.wage;
        base.cutoff = stats.qL_cutoff;
        cs.grid = stats_cs.qL_grid;
        cs.values = stats_cs.wage;
        cs.cutoff = stats_cs.qL_cutoff;
        [wage_grid,~,~,wage_pct] = GHK_intpol(base,cs);

        % interpolate salary solutions for both baseline and comparative
        % static cases over a common grid (to allow comparison of salaries)
        base.grid = stats.qH_grid;
        base.values = stats.salary_sorted;
        base.cutoff = stats.qH_cutoff;
        cs.grid = stats_cs.qH_grid;
        cs.values = stats_cs.salary_sorted;
        cs.cutoff = stats_cs.qH_cutoff;
        [salary_grid,~,~,salary_pct] = GHK_intpol(base,cs);

        % plot matching function
        figure(); hold on;
        plot(stats.qL_grid(stats.qL_cutoff_index+1:end),...
             stats.match(stats.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1));
        plot(stats.qL_grid(1:stats.qL_cutoff_index),...
             stats.match(1:stats.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2));
        plot(stats_cs.qL_grid(stats_cs.qL_cutoff_index+1:end),...
             stats_cs.match(stats_cs.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1),'LineStyle','--');
        plot(stats_cs.qL_grid(1:stats_cs.qL_cutoff_index),...
             stats_cs.match(1:stats_cs.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2),'LineStyle','--');
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('q_H','FontSize',fsize);
        mplot_leg = legend('Sector 1: baseline','Sector 2: baseline',...
                    ['Sector 1: +' num2str((p_2_mul-1)*100) '% p_2'],...
                    ['Sector 2: +' num2str((p_2_mul-1)*100) '% p_2']);
        set(mplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot percentage change in wages
        figure(); hold on;
        plot(wage_grid.high,wage_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(wage_grid.switch,wage_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(wage_grid.low,wage_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        plot(get(gca,'Xlim'),[0 0],'Color','k','LineStyle',':',...
             'LineWidth',lwidth(2));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('% change in w(q_L)','FontSize',fsize);
        wplot_leg = legend('Workers originally in sector 1',...
                       'Workers switching from sector 1 to sector 2',...
                       'Workers originally in sector 2');
        set(wplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);

        % plot percentage change in salaries
        figure(); hold on;
        plot(salary_grid.low,salary_pct.low,'Color','b',...
            'LineWidth',lwidth(1));
        plot(salary_grid.switch,salary_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(salary_grid.high,salary_pct.high,'Color','r',...
            'LineWidth',lwidth(3));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('% change in r(q_H)','FontSize',fsize);
        rplot_leg = legend('Managers originally in sector 1',...
                         'Managers switching from sector 1 to sector 2',...
                         'Managers originally in sector 2');
        set(rplot_leg,'Location','NorthWest');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        axis([1 2 0 7]);
        
    % Figure 11: 
    %   Response of matching, wage, and salary functions for case 2, HL/LH
    %   equilibria
    case 'figure 11'

        % set sector-specific parameters
        sec.gam_1 = .1;
        sec.gam_2 = .1;
        sec.alp_1 = .9;
        sec.alp_2 = .1;
        sec.bet_1 = 1-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -.5;
        sec.rho_2 = -.5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 2;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = [1 2 3];
        sol.init_wage = .1;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-5;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);

        % increase p_2 by 10% and solve for new equlibrium
        p_2_mul = 1.1;
        param_cs = param;
        param_cs.sec.p_2 = param.sec.p_2 * p_2_mul;
        stats_cs = GHK_algorithm(param_cs);

        % interpolate wage solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of wages)
        base.grid = stats.qL_grid;
        base.values = stats.wage;
        base.cutoff = stats.qL_cutoff;
        cs.grid = stats_cs.qL_grid;
        cs.values = stats_cs.wage;
        cs.cutoff = stats_cs.qL_cutoff;
        [wage_grid,~,~,wage_pct] = GHK_intpol(base,cs);

        % interpolate salary solutions for both baseline and comparative
        % static cases over a common grid (to allow comparison of salaries)
        base.grid = stats.qH_grid;
        base.values = stats.salary_sorted;
        base.cutoff = stats.qH_cutoff;
        cs.grid = stats_cs.qH_grid;
        cs.values = stats_cs.salary_sorted;
        cs.cutoff = stats_cs.qH_cutoff;
        [salary_grid,~,~,salary_pct] = GHK_intpol(base,cs);

        % plot matching function
        figure(); hold on;
        plot(stats.qL_grid(stats.qL_cutoff_index+1:end),...
             stats.match(stats.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1));
        plot(stats.qL_grid(1:stats.qL_cutoff_index),...
             stats.match(1:stats.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2));
        plot(stats_cs.qL_grid(stats_cs.qL_cutoff_index+1:end),...
             stats_cs.match(stats_cs.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1),'LineStyle','--');
        plot(stats_cs.qL_grid(1:stats_cs.qL_cutoff_index),...
             stats_cs.match(1:stats_cs.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2),'LineStyle','--');
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('q_H','FontSize',fsize);
        mplot_leg = legend('Sector 1: baseline','Sector 2: baseline',...
                    ['Sector 1: +' num2str((p_2_mul-1)*100) '% p_2'],...
                    ['Sector 2: +' num2str((p_2_mul-1)*100) '% p_2']);
        set(mplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot percentage change in wages
        figure(); hold on;
        plot(wage_grid.high,wage_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(wage_grid.switch,wage_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(wage_grid.low,wage_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        plot(get(gca,'Xlim'),[0 0],'Color','k','LineStyle',':',...
             'LineWidth',lwidth(2));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('% change in w(q_L)','FontSize',fsize);
        wplot_leg = legend('Workers originally in sector 1',...
                       'Workers switching from sector 1 to sector 2',...
                       'Workers originally in sector 2');
        set(wplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        axis([1 2 -10 45]);

        % plot percentage change in salaries
        figure(); hold on;
        plot(salary_grid.low,salary_pct.low,'Color','b',...
            'LineWidth',lwidth(1));
        plot(salary_grid.switch,salary_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(salary_grid.high,salary_pct.high,'Color','r',...
            'LineWidth',lwidth(3));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('% change in r(q_H)','FontSize',fsize);
        rplot_leg = legend('Managers originally in sector 1',...
                         'Managers switching from sector 1 to sector 2',...
                         'Managers originally in sector 2');
        set(rplot_leg,'Location','SouthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
    % Figure 12: 
    %   Response of matching, wage, and salary functions for case 3, HL/LH
    %   equilibria
    case 'figure 12'

        % set sector-specific parameters
        sec.gam_1 = .9;
        sec.gam_2 = .9;
        sec.alp_1 = .9;
        sec.alp_2 = .1;
        sec.bet_1 = 1-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -.5;
        sec.rho_2 = -.5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 2;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = [1 2 3];
        sol.init_wage = 1;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-5;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);

        % increase p_2 by 10% and solve for new equlibrium
        p_2_mul = 1.1;
        param_cs = param;
        param_cs.sec.p_2 = param.sec.p_2 * p_2_mul;
        stats_cs = GHK_algorithm(param_cs);

        % interpolate wage solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of wages)
        base.grid = stats.qL_grid;
        base.values = stats.wage;
        base.cutoff = stats.qL_cutoff;
        cs.grid = stats_cs.qL_grid;
        cs.values = stats_cs.wage;
        cs.cutoff = stats_cs.qL_cutoff;
        [wage_grid,~,~,wage_pct] = GHK_intpol(base,cs);

        % interpolate salary solutions for both baseline and comparative
        % static cases over a common grid (to allow comparison of salaries)
        base.grid = stats.qH_grid;
        base.values = stats.salary_sorted;
        base.cutoff = stats.qH_cutoff;
        cs.grid = stats_cs.qH_grid;
        cs.values = stats_cs.salary_sorted;
        cs.cutoff = stats_cs.qH_cutoff;
        [salary_grid,~,~,salary_pct] = GHK_intpol(base,cs);

        % plot matching function
        figure(); hold on;
        plot(stats.qL_grid(stats.qL_cutoff_index+1:end),...
             stats.match(stats.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1));
        plot(stats.qL_grid(1:stats.qL_cutoff_index),...
             stats.match(1:stats.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2));
        plot(stats_cs.qL_grid(stats_cs.qL_cutoff_index+1:end),...
             stats_cs.match(stats_cs.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1),'LineStyle','--');
        plot(stats_cs.qL_grid(1:stats_cs.qL_cutoff_index),...
             stats_cs.match(1:stats_cs.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2),'LineStyle','--');
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('q_H','FontSize',fsize);
        mplot_leg = legend('Sector 1: baseline','Sector 2: baseline',...
                    ['Sector 1: +' num2str((p_2_mul-1)*100) '% p_2'],...
                    ['Sector 2: +' num2str((p_2_mul-1)*100) '% p_2']);
        set(mplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot percentage change in wages
        figure(); hold on;
        plot(wage_grid.high,wage_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(wage_grid.switch,wage_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(wage_grid.low,wage_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('% change in w(q_L)','FontSize',fsize);
        wplot_leg = legend('Workers originally in sector 1',...
                       'Workers switching from sector 1 to sector 2',...
                       'Workers originally in sector 2');
        set(wplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        axis([1 2 2 12]);
        
        % plot percentage change in salaries
        figure(); hold on;
        plot(salary_grid.low,salary_pct.low,'Color','b',...
            'LineWidth',lwidth(1));
        plot(salary_grid.switch,salary_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(salary_grid.high,salary_pct.high,'Color','r',...
            'LineWidth',lwidth(3));
        plot(get(gca,'Xlim'),[0 0],'Color','k','LineStyle',':',...
             'LineWidth',lwidth(2));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('% change in r(q_H)','FontSize',fsize);
        rplot_leg = legend('Managers originally in sector 1',...
                         'Managers switching from sector 1 to sector 2',...
                         'Managers originally in sector 2');
        set(rplot_leg,'Location','SouthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
    % Figure 13: 
    %   Response of matching, wage, and salary functions for case 4, HL/LH
    %   equilibria
    case 'figure 13'

        % set sector-specific parameters
        sec.gam_1 = .4;
        sec.gam_2 = .6;
        sec.alp_1 = .5;
        sec.alp_2 = .5;
        sec.bet_1 = 1-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -.5;
        sec.rho_2 = -.5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 2;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = [1 2 3];
        sol.init_wage = 1;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-5;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);

        % increase p_2 by 10% and solve for new equlibrium
        p_2_mul = 1.1;
        param_cs = param;
        param_cs.sec.p_2 = param.sec.p_2 * p_2_mul;
        stats_cs = GHK_algorithm(param_cs);

        % interpolate wage solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of wages)
        base.grid = stats.qL_grid;
        base.values = stats.wage;
        base.cutoff = stats.qL_cutoff;
        cs.grid = stats_cs.qL_grid;
        cs.values = stats_cs.wage;
        cs.cutoff = stats_cs.qL_cutoff;
        [wage_grid,~,~,wage_pct] = GHK_intpol(base,cs);

        % interpolate salary solutions for both baseline and comparative
        % static cases over a common grid (to allow comparison of salaries)
        base.grid = stats.qH_grid;
        base.values = stats.salary_sorted;
        base.cutoff = stats.qH_cutoff;
        cs.grid = stats_cs.qH_grid;
        cs.values = stats_cs.salary_sorted;
        cs.cutoff = stats_cs.qH_cutoff;
        [salary_grid,~,~,salary_pct] = GHK_intpol(base,cs);

        % plot matching function
        figure(); hold on;
        plot(stats.qL_grid(stats.qL_cutoff_index+1:end),...
             stats.match(stats.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1));
        plot(stats.qL_grid(1:stats.qL_cutoff_index),...
             stats.match(1:stats.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2));
        plot(stats_cs.qL_grid(stats_cs.qL_cutoff_index+1:end),...
             stats_cs.match(stats_cs.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1),'LineStyle','--');
        plot(stats_cs.qL_grid(1:stats_cs.qL_cutoff_index),...
             stats_cs.match(1:stats_cs.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2),'LineStyle','--');
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('q_H','FontSize',fsize);
        mplot_leg = legend('Sector 1: baseline','Sector 2: baseline',...
                    ['Sector 1: +' num2str((p_2_mul-1)*100) '% p_2'],...
                    ['Sector 2: +' num2str((p_2_mul-1)*100) '% p_2']);
        set(mplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot percentage change in wages
        figure(); hold on;
        plot(wage_grid.high,wage_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(wage_grid.switch,wage_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(wage_grid.low,wage_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('% change in w(q_L)','FontSize',fsize);
        wplot_leg = legend('Workers originally in sector 1',...
                       'Workers switching from sector 1 to sector 2',...
                       'Workers originally in sector 2');
        set(wplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot percentage change in salaries
        figure(); hold on;
        plot(salary_grid.low,salary_pct.low,'Color','b',...
            'LineWidth',lwidth(1));
        plot(salary_grid.switch,salary_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(salary_grid.high,salary_pct.high,'Color','r',...
            'LineWidth',lwidth(3));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('% change in r(q_H)','FontSize',fsize);
        rplot_leg = legend('Managers originally in sector 1',...
                         'Managers switching from sector 1 to sector 2',...
                         'Managers originally in sector 2');
        set(rplot_leg,'Location','SouthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
    % Figure 14: 
    %   Response of matching, wage, and salary functions for case 5, HL/LH
    %   equilibria
    case 'figure 14'

        % set sector-specific parameters
        sec.gam_1 = .7;
        sec.gam_2 = .3;
        sec.alp_1 = .9;
        sec.alp_2 = .1;
        sec.bet_1 = 1-sec.alp_1;
        sec.bet_2 = 1-sec.alp_2;
        sec.rho_1 = -.5;
        sec.rho_2 = -.5;
        sec.psi_1 = @(qH,qL) (sec.alp_1*qL.^sec.rho_1+...
                    sec.bet_1*qH.^sec.rho_1).^...
                    ((sec.alp_1+sec.bet_1)/sec.rho_1);
        sec.psi_2 = @(qH,qL) (sec.alp_2*qL.^sec.rho_2+...
                    sec.bet_2*qH.^sec.rho_2).^...
                    ((sec.alp_2+sec.bet_2)/sec.rho_2);
        sec.p_1 = 1;
        sec.p_2 = 1;

        % set factor-specific parameters
        fac.qL_min = 1;
        fac.qL_max = 2;
        fac.qH_min = 1;
        fac.qH_max = 2;
        fac.L = 1;
        fac.H = 1;
        fac.k_L = 3;
        fac.k_H = 3;
        fac.phi_L = @(qL) fac.k_L*fac.qL_min^fac.k_L*qL.^(-fac.k_L-1)...
                /(1-(fac.qL_min/fac.qL_max)^fac.k_L);
        fac.phi_H = @(qH) fac.k_H*fac.qH_min^fac.k_H*qH.^(-fac.k_H-1)...
                /(1-(fac.qH_min/fac.qH_max)^fac.k_H);

        % set solver parameters
        sol.eq_type = [1 2 3];
        sol.init_wage = 1;
        sol.qL_gridSize = 200;
        sol.salary_tol = 1E-5;
        sol.max_iter = 100;
        sol.bvp4c_opt = bvpset('AbsTol',1e-6,'RelTol',1e-6);
        sol.display = 1;

        % store parameters to supply to solver
        param.sec = sec;
        param.fac = fac;
        param.sol = sol;

        % solve for baseline equilibrium
        stats = GHK_algorithm(param);

        % increase p_2 by 10% and solve for new equlibrium
        p_2_mul = 1.1;
        param_cs = param;
        param_cs.sec.p_2 = param.sec.p_2 * p_2_mul;
        stats_cs = GHK_algorithm(param_cs);

        % interpolate wage solutions for both baseline and comparative 
        % static cases over a common grid (to allow comparison of wages)
        base.grid = stats.qL_grid;
        base.values = stats.wage;
        base.cutoff = stats.qL_cutoff;
        cs.grid = stats_cs.qL_grid;
        cs.values = stats_cs.wage;
        cs.cutoff = stats_cs.qL_cutoff;
        [wage_grid,~,~,wage_pct] = GHK_intpol(base,cs);

        % interpolate salary solutions for both baseline and comparative
        % static cases over a common grid (to allow comparison of salaries)
        base.grid = stats.qH_grid;
        base.values = stats.salary_sorted;
        base.cutoff = stats.qH_cutoff;
        cs.grid = stats_cs.qH_grid;
        cs.values = stats_cs.salary_sorted;
        cs.cutoff = stats_cs.qH_cutoff;
        [salary_grid,~,~,salary_pct] = GHK_intpol(base,cs);

        % plot matching function
        figure(); hold on;
        plot(stats.qL_grid(stats.qL_cutoff_index+1:end),...
             stats.match(stats.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1));
        plot(stats.qL_grid(1:stats.qL_cutoff_index),...
             stats.match(1:stats.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2));
        plot(stats_cs.qL_grid(stats_cs.qL_cutoff_index+1:end),...
             stats_cs.match(stats_cs.qL_cutoff_index+1:end),...
             'Color','b','LineWidth',lwidth(1),'LineStyle','--');
        plot(stats_cs.qL_grid(1:stats_cs.qL_cutoff_index),...
             stats_cs.match(1:stats_cs.qL_cutoff_index),...
             'Color','r','LineWidth',lwidth(2),'LineStyle','--');
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('q_H','FontSize',fsize);
        mplot_leg = legend('Sector 1: baseline','Sector 2: baseline',...
                    ['Sector 1: +' num2str((p_2_mul-1)*100) '% p_2'],...
                    ['Sector 2: +' num2str((p_2_mul-1)*100) '% p_2']);
        set(mplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot percentage change in wages
        figure(); hold on;
        plot(wage_grid.high,wage_pct.high,'Color','b',...
            'LineWidth',lwidth(1));
        plot(wage_grid.switch,wage_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(wage_grid.low,wage_pct.low,'Color','r',...
            'LineWidth',lwidth(3));
        hold off;
        xlabel('q_L','FontSize',fsize);
        ylabel('% change in w(q_L)','FontSize',fsize);
        wplot_leg = legend('Workers originally in sector 1',...
                       'Workers switching from sector 1 to sector 2',...
                       'Workers originally in sector 2');
        set(wplot_leg,'Location','NorthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
        
        % plot percentage change in salaries
        figure(); hold on;
        plot(salary_grid.low,salary_pct.low,'Color','b',...
            'LineWidth',lwidth(1));
        plot(salary_grid.switch,salary_pct.switch,'Color','m',...
             'LineStyle','--','LineWidth',lwidth(2));
        plot(salary_grid.high,salary_pct.high,'Color','r',...
            'LineWidth',lwidth(3));
        hold off;
        xlabel('q_H','FontSize',fsize);
        ylabel('% change in r(q_H)','FontSize',fsize);
        rplot_leg = legend('Managers originally in sector 1',...
                         'Managers switching from sector 1 to sector 2',...
                         'Managers originally in sector 2');
        set(rplot_leg,'Location','SouthEast');
        set(gca,'FontSize',fsize);
        set(gca,'LineWidth',awidth);
end