% Title: GHK_intpol.m
% Date: 5/15/2015
% Author: Kevin Lim
% Description: 
%   This function takes wage/salary solutions from the GHK model when there
%   are two regions of sorting, and interpolates them over a common grid to 
%   allow comparison of baseline and comparative static equilibria.
%
%   Inputs to the function are structures base and cs giving solutions for 
%   baseline and comaparative static case respectively. Structures base and
%   cs must both have the following three fields:
%       - grid: grid over which values are defined
%       - values: vector of values
%       - cutoff: cutoff grid value defining region of sorting
%
%   Outputs of the function are structures grid, base_values, and 
%   cs_values, pct_values giving the interpolated grid points, baseline 
%   values, comparative static values, and percentage change in values 
%   respectively. Structures grid, base_values, cs_values, and pct_values 
%   each have three fields:
%       - low: grid points / values corresponding to agents remaining
%              in low sector
%       - switch: grid points / values corresponding to agents switching
%                 sectors
%       - high: grid points / values corresponding to agents remaining
%               in high sector

function [grid,base_values,cs_values,pct_values] = GHK_intpol(base,cs)

    % tolerance for difference between cutoffs
    difftol = 1E-5;
    
    % minimum and maximum grid values
    min_value = min(min(base.grid),min(cs.grid));
    max_value = max(max(base.grid),max(cs.grid));
    
    % number of grid points
    ngrid = max(length(base.grid),length(cs.grid));
    
    % cutoff indices
    base.cutoff_index = find(base.grid==base.cutoff,1);
    cs.cutoff_index = find(cs.grid==cs.cutoff,1);
    
    % interpolate values for both baseline and comparative static cases
    % over a common grid (to allow comparison of values)
    if base.cutoff < cs.cutoff  && abs(base.cutoff-cs.cutoff)>difftol

        % values of agents that remain in low sector
        grid.low = linspace(min_value,base.cutoff,round((base.cutoff-...
                   min_value)/(max_value-min_value)*ngrid));
        base_values.low = pchip(base.grid(1:base.cutoff_index),...
                          base.values(1:base.cutoff_index),grid.low);
        cs_values.low = pchip(cs.grid(cs.grid <= base.cutoff),...
                        cs.values(cs.grid <= base.cutoff),grid.low);

        % values of agents that switch from high to low sector
        grid.switch = linspace(base.cutoff,cs.cutoff,round((cs.cutoff-...
                      base.cutoff)/(max_value-min_value)*ngrid));
        base_values.switch = pchip(base.grid(base.cutoff_index+1:(find(...
                             base.grid > cs.cutoff,1)-1)),base.values(...
                             base.cutoff_index+1:(find(base.grid>...
                             cs.cutoff,1)-1)),grid.switch);
        cs_values.switch = pchip(cs.grid(find(cs.grid>=base.cutoff,1):...
                           cs.cutoff_index),cs.values(find(cs.grid>=...
                           base.cutoff,1):cs.cutoff_index),grid.switch);
        
        % values of agents that remain in high sector
        grid.high = linspace(cs.cutoff,max_value,round((max_value-...
                       cs.cutoff)/(max_value-min_value)*ngrid));
        base_values.high = pchip(base.grid(find(base.grid>=...
                           cs.cutoff,1):end),base.values(find(...
                           base.grid>= cs.cutoff,1):end),grid.high);
        cs_values.high = pchip(cs.grid(cs.cutoff_index+1:end),...
                         cs.values(cs.cutoff_index+1:end),grid.high);
                                      

    elseif base.cutoff > cs.cutoff && abs(base.cutoff-cs.cutoff)>difftol

        % values of agents that remain in low sector
        grid.low = linspace(min_value,cs.cutoff,round((cs.cutoff-...
                   min_value)/(max_value-min_value)*ngrid));
        base_values.low = pchip(base.grid(base.grid <= cs.cutoff),...
                          base.values(base.grid <= cs.cutoff),grid.low);
        cs_values.low = pchip(cs.grid(1:cs.cutoff_index),...
                        cs.values(1:cs.cutoff_index),grid.low);
                    
                    

        % values of agents that switch from low to high sector
        grid.switch = linspace(cs.cutoff,base.cutoff,round((base.cutoff-...
                      cs.cutoff)/(max_value-min_value)*ngrid));
        base_values.switch = pchip(base.grid(find(base.grid>=...
                             cs.cutoff,1):base.cutoff_index),...
                             base.values(find(base.grid>=cs.cutoff,1):...
                             base.cutoff_index),grid.switch);
        cs_values.switch = pchip(cs.grid(cs.cutoff_index+1:(find(...
                           cs.grid>base.cutoff,1)-1)),cs.values(...
                           cs.cutoff_index+1:(find(cs.grid>base.cutoff,...
                           1)-1)),grid.switch);

        % values of agents that remain in high sector
        grid.high = linspace(base.cutoff,max_value,round((max_value-...
                       base.cutoff)/(max_value-min_value)*ngrid));
        base_values.high = pchip(base.grid(base.cutoff_index+1:end),...
                           base.values(base.cutoff_index+1:end),...
                           grid.high);
        cs_values.high = pchip(cs.grid(find(cs.grid>=base.cutoff,1):...
                         end),cs.values(find(cs.grid >= base.cutoff,1):...
                         end),grid.high);                   

    else

        % values of agents that remain in low sector
        grid.low = linspace(min_value,base.cutoff,round((base.cutoff-...
                   min_value)/(max_value-min_value)*ngrid));
        base_values.low = pchip(base.grid(1:cutoff_index),...
                          base.values(1:cutoff_index),grid.low);
        cs_values.low = pchip(cs.grid(1:cutoff_index),...
                        cs.values(1:cutoff_index),grid.low);
        
        % values of agents that switch from low to high sector
        grid.switch = [];
        base_values.switch = [];
        cs_values.switch = [];

        % values of agents that remain in high sector
        grid.high = linspace(cs.cutoff,max_value,round((max_value-...
                       cs.cutoff)/(max_value-min_value)*ngrid));
        base_values.high = pchip(base.grid(base.cutoff_index+1:end),...
                           base.values(base.cutoff_index+1:end),...
                           grid.high);
        cs_values.high = pchip(cs.grid(cs.cutoff_index+1:end),...
                         cs.values(cs.cutoff_index+1:end),grid.high);

    end

    % compute percentage change in values
    pct_values.low = (cs_values.low./base_values.low-1)*100;
    if abs(base.cutoff-cs.cutoff)>difftol
        pct_values.switch = (cs_values.switch./base_values.switch-1)*100;
    else
        pct_values.switch = [];
    end
    pct_values.high = (cs_values.high./base_values.high-1)*100;
 
end